session

package
v1.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Session

type Session struct {
	// contains filtered or unexported fields
}

func SessionFromTokenSource

func SessionFromTokenSource(src oauth2.TokenSource, config auth.Config, ctx context.Context) (s *Session, err error)

SessionFromTokenSource creates a session from an XBOX token source and returns it.

func (*Session) LegacyMultiplayerXBL

func (s *Session) LegacyMultiplayerXBL(ctx context.Context) (tok *auth.XBLToken, err error)

LegacyMultiplayerXBL requests an XBL token for the old multiplayer endpoint.

func (*Session) MCToken

func (s *Session) MCToken(ctx context.Context) (*service.Token, error)

MCToken returns the session token, or refreshes it if it has expired.

func (*Session) MultiplayerToken

func (s *Session) MultiplayerToken(ctx context.Context, key *ecdsa.PublicKey) (jwt string, err error)

MultiplayerToken requests a multiplayer token from Microsoft. The token can be reused, but is not reused by the vanilla client.

func (*Session) PlayfabIdentity

func (s *Session) PlayfabIdentity(ctx context.Context) (*playfab.Identity, error)

PlayfabIdentity returns the user's Playfab identity, which includes the session ticket.

func (*Session) RequestXBLToken

func (s *Session) RequestXBLToken(ctx context.Context, relyingParty string) (*auth.XBLToken, error)

Obtainer returns the Xbox token obtainer, which contains the device token

func (*Session) Token

func (s *Session) Token() (*oauth2.Token, error)

Jump to