Documentation
¶
Index ¶
- type Session
- func (s *Session) LegacyMultiplayerXBL(ctx context.Context) (tok *auth.XBLToken, err error)
- func (s *Session) MCToken(ctx context.Context) (*service.Token, error)
- func (s *Session) MultiplayerToken(ctx context.Context, key *ecdsa.PublicKey) (jwt string, err error)
- func (s *Session) PlayfabIdentity(ctx context.Context) (*playfab.Identity, error)
- func (s *Session) RequestXBLToken(ctx context.Context, relyingParty string) (*auth.XBLToken, error)
- func (s *Session) Token() (*oauth2.Token, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Session ¶
type Session struct {
// contains filtered or unexported fields
}
func SessionFromTokenSource ¶
func SessionFromTokenSource(src oauth2.TokenSource, config auth.Config, ctx context.Context) (s *Session, err error)
SessionFromTokenSource creates a session from an XBOX token source and returns it.
func (*Session) LegacyMultiplayerXBL ¶
LegacyMultiplayerXBL requests an XBL token for the old multiplayer endpoint.
func (*Session) MultiplayerToken ¶
func (s *Session) MultiplayerToken(ctx context.Context, key *ecdsa.PublicKey) (jwt string, err error)
MultiplayerToken requests a multiplayer token from Microsoft. The token can be reused, but is not reused by the vanilla client.
func (*Session) PlayfabIdentity ¶
PlayfabIdentity returns the user's Playfab identity, which includes the session ticket.
func (*Session) RequestXBLToken ¶
Obtainer returns the Xbox token obtainer, which contains the device token
Click to show internal directories.
Click to hide internal directories.