Documentation
¶
Index ¶
- func FetchPrivateField[T any](s any, name string) T
- func ShowAlert(canvas fyne.Canvas, label string, button string, closeFunc func())
- func UpdatePrivateField[T any](v any, name string, value T)
- type FixedSizeLayout
- type FixedSizeLayoutExpand
- type NethernetConnWithHeader
- type Pinger
- type ServerStatus
- type TextEntry
- type TextStyle
- type WidgetWithLabel
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FetchPrivateField ¶
FetchPrivateField fetches a private field.
func UpdatePrivateField ¶
UpdatePrivateField sets a private field to the value passed.
Types ¶
type FixedSizeLayout ¶
type FixedSizeLayout struct {
// contains filtered or unexported fields
}
func NewFixedSizeLayout ¶
func NewFixedSizeLayout(size fyne.Size) *FixedSizeLayout
func NewFixedSizeLayoutExpand ¶
func NewFixedSizeLayoutExpand(size fyne.Size) *FixedSizeLayout
func (FixedSizeLayout) Layout ¶
func (m FixedSizeLayout) Layout(objects []fyne.CanvasObject, size fyne.Size)
func (FixedSizeLayout) MinSize ¶
func (m FixedSizeLayout) MinSize(objects []fyne.CanvasObject) fyne.Size
type FixedSizeLayoutExpand ¶
type FixedSizeLayoutExpand struct {
// contains filtered or unexported fields
}
func (FixedSizeLayoutExpand) Layout ¶
func (m FixedSizeLayoutExpand) Layout(objects []fyne.CanvasObject, size fyne.Size)
func (FixedSizeLayoutExpand) MinSize ¶
func (m FixedSizeLayoutExpand) MinSize(objects []fyne.CanvasObject) fyne.Size
type NethernetConnWithHeader ¶
func (*NethernetConnWithHeader) ReadPacket ¶
func (g *NethernetConnWithHeader) ReadPacket() ([]byte, error)
type Pinger ¶
type Pinger struct {
// contains filtered or unexported fields
}
func (*Pinger) AddServer ¶
func (p *Pinger) AddServer(ipStr string, statusFunc func(s ServerStatus)) error
func (*Pinger) RemoveServer ¶
type ServerStatus ¶
type ServerStatus struct {
// ServerName is the name or MOTD of the server, as shown in the server list.
ServerName string
// ProtocolID is the main protocol id accepted by the server
ProtocolID int
// Version is the main version that the server supports
Version string
// PlayerCount is the current amount of players displayed in the list.
PlayerCount int
// MaxPlayers is the maximum amount of players in the server. If set to 0, MaxPlayers is set to
// PlayerCount + 1.
MaxPlayers int
// RaknetID is the server's Raknet ID
RaknetID int
// WorldName is the world name of the server
WorldName string
// GameMode is the gamemode of the server
GameMode string
}
type TextStyle ¶
type TextStyle uint8
func (TextStyle) Obfuscated ¶
func (TextStyle) SetObfuscated ¶
type WidgetWithLabel ¶
type WidgetWithLabel[T fyne.CanvasObject] struct { // contains filtered or unexported fields }
func NewObjectWithLabel ¶
func NewObjectWithLabel[T fyne.CanvasObject](label string, obj T) *WidgetWithLabel[T]
func (*WidgetWithLabel[T]) Container ¶
func (e *WidgetWithLabel[T]) Container() *fyne.Container
func (*WidgetWithLabel[T]) Obj ¶
func (e *WidgetWithLabel[T]) Obj() T
Click to show internal directories.
Click to hide internal directories.